==> vue-checkbox-group-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/checkbox-group/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import Checkbox from "@dftvue2-opentiny/vue-checkbox";
import CheckboxButton from "@dftvue2-opentiny/vue-checkbox-button";
import "@dftvue2-opentiny/vue-theme/checkbox-group/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    Checkbox,
    CheckboxButton
  },
  props: [].concat(props, ["modelValue", "type", "options", "disabled", "min", "max", "size", "fill", "textColor", "vertical"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-checkbox-group",
    class: _vm.vertical ? "is-vertical" : "",
    attrs: {
      "role": "group",
      "aria-label": "checkbox-group"
    }
  }, [_vm._t("default", function() {
    return [_vm.type === "checkbox" ? _vm._l(_vm.options, function(item, index) {
      return _c("checkbox", _vm._b({
        key: index
      }, "checkbox", item, false));
    }) : _vm._e(), _vm.type === "button" ? _vm._l(_vm.options, function(item, index) {
      return _c("checkbox-button", _vm._b({
        key: index
      }, "checkbox-button", item, false));
    }) : _vm._e()];
  })], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-checkbox-group-2.21.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/checkbox-group/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import Checkbox from '@opentinyvue/vue-checkbox';
import CheckboxButton from '@opentinyvue/vue-checkbox-button';
import '@opentinyvue/vue-theme/checkbox-group/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    Checkbox,
    CheckboxButton
  },
  props: [].concat(props, ["modelValue", "type", "options", "disabled", "min", "max", "size", "fill", "textColor", "vertical", "displayOnly", "shape"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-checkbox-group",
    class: _vm.vertical ? "is-vertical" : "",
    attrs: {
      "role": "group",
      "aria-label": "checkbox-group"
    }
  }, [_vm._t("default", function() {
    return [_vm.type === "checkbox" ? _vm._l(_vm.options, function(item, index) {
      return _c("checkbox", _vm._b({
        key: index
      }, "checkbox", item, false));
    }) : _vm._e(), _vm.type === "button" ? _vm._l(_vm.options, function(item, index) {
      return _c("checkbox-button", _vm._b({
        key: index
      }, "checkbox-button", item, false));
    }) : _vm._e()];
  })], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
